@@ -10,11 +10,11 @@ FSM::Basic - Finite state machine using HASH as state definitions
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 =head1 SYNOPSIS
 
@@ -277,9 +277,11 @@ sub run {
                     if ($in =~ /$key/) {
                         if (@+) {
                             for my $nbr (1 .. (scalar(@+)-1)) {
-                                my $match = substr($in, $-[$nbr], $+[$nbr] - $-[$nbr]);
-                                if (defined($+[$nbr])) {
-                                    $self->{cmd_regex}{$nbr} = substr($in, $-[$nbr], $+[$nbr] - $-[$nbr]);
+                                if ( defined $-[$nbr] ) {
+                                    my $match = substr($in, $-[$nbr], $+[$nbr] - $-[$nbr]);
+                                    if (defined($+[$nbr])) {
+                                        $self->{cmd_regex}{$nbr} = substr($in, $-[$nbr], $+[$nbr] - $-[$nbr]);
+                                    }
                                 }
                             }
                         }
